/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { t, validateNonEmpty } from '@superset-ui/core';
import {
  ControlPanelConfig,
  sections,
  sharedControls,
} from '@superset-ui/chart-controls';

const config: ControlPanelConfig = {
  /**
   * 控制面板分为两个选项卡： “查询 “和 ”图表选项"。
   * 定义图表数据请求输入（如列和度量）的控件通常位于 “查询 ”部分，
   * 而影响图表视觉外观或功能的控件则位于 “图表选项 ”部分。
   *
   * 下面有几种预定义控件可以使用.
   * 如下:
   * - groupby: 按列分组（转换为 GROUP BY 语句）
   * - series: 与 groupby 相同，但只有一个选择。
   * - metrics: 多个度量（转换为聚合表达式：Sum、Avg、Max、Min等）
   * - metric: 与 metrics 相同，但只有一个选择。
   * - adhoc_filters:过滤器（根据过滤器类型转换为 WHERE 或 HAVING）
   * - row_limit: 最大记录数（转换为 LIMIT 语句）
   *
   * 如果控制面板上同时有`series`和`groupby`控件，而用户选择`col1`作为`series`控件的值，并且`col2` 和 `col3` 作为`groupby`控件的值。
   * 结果查询将包含三个`groupby`列。
   * 这是因为我们认为 `series` 控件是一个 `groupby` 查询字段，其值将在生成查询时自动追加到 `groupby` 字段。
   * 
   * 还可以通过导入必要的依赖关系和覆盖默认参数来定义自定义控件，
   * 然后将其放置在 “查询 ”部分的 “controlSetRows ”部分，而不是预定义控件中。
   *
   * import { validateNonEmpty } from '@superset-ui/core';
   * import {
   *   sharedControls,
   *   ControlConfig,
   *   ControlPanelConfig,
   * } from '@superset-ui/chart-controls';
   *
   * const myControl: ControlConfig<'SelectControl'> = {
   *   name: 'secondary_entity',
   *   config: {
   *     ...sharedControls.entity,
   *     type: 'SelectControl',
   *     label: t('Secondary Entity'),
   *     mapStateToProps: state => ({
   *       sharedControls.columnChoices(state.datasource)
   *       .columns.filter(c => c.groupby)
   *     })
   *     validators: [validateNonEmpty],
   *   },
   * }
   *
   * 除了基本的下拉控件外，还有几种预定义的控件类型（可通过 `type` 属性设置）可以使用。
   * 一些常用的示例如下：
   * - SelectControl: 用于选择单个或多个值的下拉菜单，通常为列
   * - MetricsControl: 下拉选择度量标准，触发模态  来定义指标详情
   * - AdhocFilterControl: 控制选择过滤器
   * - CheckboxControl: 用于选择真/假值的复选框
   * - SliderControl: 带有最小/最大值的滑块
   * - TextControl: 文本数据控制
   *
   * 要了解更多控制输入类型，请查看 `incubator-superset` 软件源并打开以下文件:
   * superset-frontend/src/explore/components/controls/index.js
   *
   * 为确保正确填写所有控件，提供了以下验证器
   * 来自 `@superset-ui/core/lib/validator`:
   * - validateNonEmpty: 必须且至少有一个值
   * - validateInteger: 必须是整数值
   * - validateNumber: 必须是整数或小数值
   */

  // For control input types, see: superset-frontend/src/explore/components/controls/index.js
  controlPanelSections: [
    
    {
      label: t('Query'),
      expanded: true,
      controlSetRows: [
        [
          {
            name: 'cols',
            config: {
              ...sharedControls.groupby,
              label: t('Columns'),
              description: t('Columns to group by'),
            },
          },
        ],
        [
          {
            name: 'metrics',
            config: {
              ...sharedControls.metrics,
              // it's possible to add validators to controls if
              // certain selections/types need to be enforced
              validators: [validateNonEmpty],
            },
          },
        ],
        ['adhoc_filters'],
        [
          {
            name: 'row_limit',
            config: sharedControls.row_limit,
          },
        ],
      ],
    },
    {
      label: t('Hello Controls!'),
      expanded: true,
      controlSetRows: [
        [
          {
            name: 'header_text',
            config: {
              type: 'TextControl',
              default: 'Hello, World!',
              renderTrigger: true,
              // ^ this makes it apply instantaneously, without triggering a "run query" button
              label: t('Header Text'),
              description: t('The text you want to see in the header'),
            },
          },
        ],
        [
          {
            name: 'bold_text',
            config: {
              type: 'CheckboxControl',
              label: t('Bold Text'),
              renderTrigger: true,
              default: true,
              description: t('A checkbox to make the '),
            },
          },
        ],
        [
          {
            name: 'header_font_size',
            config: {
              type: 'SelectControl',
              label: t('Font Size'),
              default: 'xl',
              choices: [
                // [value, label]
                ['xxs', 'xx-small'],
                ['xs', 'x-small'],
                ['s', 'small'],
                ['m', 'medium'],
                ['l', 'large'],
                ['xl', 'x-large'],
                ['xxl', 'xx-large'],
              ],
              renderTrigger: true,
              description: t('The size of your header font'),
            },
          },
        ],
      ],
    },
  ],
};

export default config;
