/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { ChartProps, TimeseriesDataRecord } from '@superset-ui/core';

export default function transformProps(chartProps: ChartProps) {
  /**
   * 从图表数据端点收到成功响应后调用此函数，用于在将传入数据发送到可视化之前对其进行转换。
   *
   * transformProps 函数在向数据可视化组件返回额外的/修改的Props时也非常有用。
   * 您也可以从 SupersetPluginChartHelloWorld.tsx 文件访问 formData，
   * 但在这里提供自定义props通常便于集成依赖特定props的第三方库。
   *
   * 对 `chartProps` 中属性的描述:
   * - `height`, `width`: 图表所在 DOM 元素的高度/宽度
   * - `formData`: 发送到后端的图表数据请求有效载荷。
   * - `queriesData`: 接收到的图表数据响应的有效载荷
   *   从后端获取。queriesData` 的一些重要属性:
   *   - `data`: 是一个包含数据的数组，每一行都包含一个将列/别名映射到其值的对象。例如:
   *     `[{ col1: 'abc', metric1: 10 }, { col1: 'xyz', metric1: 20 }]`
   *   - `rowcount`:  `data`中的行数
   *   - `query`: 发出的查询。
   *
   * 请注意：应用程序加载时会缓存 transformProps 函数。
   * 在开发过程中通过热加载对 `transformProps` 函数进行更改时，只有重新启动开发服务器才能看到更改。
   */
  const { width, height, formData, queriesData } = chartProps;
  const { boldText, headerFontSize, headerText } = formData;
  const data = queriesData[0].data as TimeseriesDataRecord[];

  console.log('formData via TransformProps.ts', formData);

  return {
    width,
    height,
    data,
    // and now your control data, manipulated as needed, and passed through as props!
    boldText,
    headerFontSize,
    headerText,
  };
}
